import {
  select,
  csv,
  scaleLinear,
  extent,
  axisLeft,
  axisBottom,
  scaleOrdinal
} from 'd3';

const svg = select('svg');

const width = +svg.attr('width');
const height = +svg.attr('height');

const render = data => {
  const title = 'Avocados: Weekly Volume vs. Average Price';
  
  const xValue = d => d.TotalVolume;
  const xAxisLabel = 'Total Volume [Millions]';
  
  const yValue = d => d.AveragePrice;
  const circleRadius = 6;
  const yAxisLabel = 'Average Price [Dollars]';
  
  const colorValue = d => d.year;
  
  const margin = { top: 60, right: 40, bottom: 88, left: 150 };
  const innerWidth = width - margin.left - margin.right;
  const innerHeight = height - margin.top - margin.bottom;
  
  const xScale = scaleLinear()
    .domain(extent(data, xValue))
    .range([0, innerWidth])
    .nice();
  
  const yScale = scaleLinear()
    .domain(extent(data, yValue))
    .range([innerHeight, 0])
    .nice();
  
  const colorScale = scaleOrdinal()
    .domain(["2016","2017","2018"])
    .range(["#4286f4","#3b424f","#319b17"]);
  
  const g = svg.append('g')
    .attr('transform', `translate(${margin.left},${margin.top})`);
  
  const xAxis = axisBottom(xScale)
    .tickSize(-innerHeight)
    .tickPadding(15);
  
  const yAxis = axisLeft(yScale)
    .tickSize(-innerWidth)
    .tickPadding(10);
  
  const yAxisG = g.append('g').call(yAxis);
  yAxisG.selectAll('.domain').remove();
  
  yAxisG.append('text')
      .attr('class', 'axis-label')
      .attr('y', -93)
      .attr('x', -innerHeight / 2)
      .attr('fill', 'black') 
      .attr('transform', `rotate(-90)`)
      .attr('text-anchor', 'middle')
      .text(yAxisLabel);
  
  const xAxisG = g.append('g').call(xAxis)
    .attr('transform', `translate(0,${innerHeight})`);
  
  xAxisG.select('.domain').remove();
  
  xAxisG.append('text')
      .attr('class', 'axis-label')
      .attr('y', 75)
      .attr('x', innerWidth / 2)
      .attr('fill', 'black')
      .text(xAxisLabel);
  
  g.selectAll('circle').data(data)
    .enter().append('circle')
      .attr('cy', d => yScale(yValue(d)))
      .attr('cx', d => xScale(xValue(d)))
      .attr('r', circleRadius)
      .attr('fill', d => colorScale(d.year));
  
  g.append('text')
      .attr('class', 'title')
      .attr('y', -10)
      .text(title);
  
  // Reference: http://bl.ocks.org/weiglemc/6185069
  // draw legend
  var legend = svg.selectAll(".legend")
      .data(colorScale.domain())
    .enter().append("g")
      .attr("class", "legend")
      .attr("transform", (d, i) => `translate(-40,${(i + 8.5) * 20})`);

  // draw legend colored rectangles
  legend.append("rect")
      .attr("x", width - 18)
      .attr("y", -110)
      .attr("width", 18)
      .attr("height", 18)
      .style("fill", colorScale);
  
  // draw legend text
  legend.append("text")
      .attr("x", width - 24)
      .attr("y", -105)
      .attr("dy", ".6em")
      .style("text-anchor", "end")
      .text(function(d) { return d;})
};

csv('https://vizhub.com/jons288/datasets/avocado2.csv')
  .then(data => {
    data.forEach(d => {
   
      d.year = +d.year;  
      d.AveragePrice = +d.AveragePrice;  
      d.TotalVolume = +d.TotalVolume/1000000;
      d.year = +d.year;
  
      
    });
    render(data);
  });





